"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateCtor = exports.argsFromObj = void 0;
var _1 = require(".");
var ctor_ensure_decorator_1 = require("./ctor-ensure.decorator");
/**
 * Extract all constructor arguments form a plain object
 * @param clazz Class to get constructor args from
 * @param value Plain object to extract from
 * @returns List of arguments in right order
 */
var argsFromObj = function (clazz, value) {
    // Get all controls of this class and find the highest validated ctor index
    var className = Reflect.getOwnMetadata(_1.META_KEY_DISPLAYNAME, clazz);
    // Not a @CtorEnsure class
    if (!className)
        return null;
    var ctls = (0, ctor_ensure_decorator_1.getActiveControls)(clazz, className, []);
    var maxCtorInd = ctls.reduce(function (acc, curr) { return (curr.ctorInd > acc ? curr.ctorInd : acc); }, 0);
    // Constructor arguments list, map value fields to their indices
    var ctorArgs = new Array(maxCtorInd + 1).fill(undefined);
    ctls.forEach(function (ctl) {
        var currValue = value[ctl.displayName];
        ctorArgs[ctl.ctorInd] = currValue;
    });
    return ctorArgs;
};
exports.argsFromObj = argsFromObj;
/**
 * Validate a constructor from the k-v pairs of a plain object
 * @param className Schema name
 * @param value Plain object containing contructor fields
 * @param templateLang Language to use for rendering ensure templates
 * @returns List of errors
 */
var validateCtor = function (className, value, templateLang) {
    var _a;
    if (templateLang === void 0) { templateLang = ''; }
    // Find target class
    var clazz = (_a = ctor_ensure_decorator_1.classRegistry[className]) === null || _a === void 0 ? void 0 : _a.clazz;
    if (!clazz)
        return null;
    var args = (0, exports.argsFromObj)(clazz, value);
    if (!args)
        return null;
    // Call validation
    return (0, ctor_ensure_decorator_1.validateClassCtor)(className, args, templateLang);
};
exports.validateCtor = validateCtor;
//# sourceMappingURL=ctor-validator.js.map